package com.ruoyi.system.service.impl.projectV2;

import com.ruoyi.system.domain.projectV2.ZsyzFj;
import com.ruoyi.system.mapper.projectV2.ZsyzFjMapper;
import com.ruoyi.system.service.projectV2.IZsyzFjService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 招商引资_附件Service业务层处理
 * 
 * @author 博曼
 * @date 2023-02-22
 */
@Service
public class ZsyzFjServiceImpl implements IZsyzFjService
{
    @Autowired
    private ZsyzFjMapper zsyzFjMapper;

    /**
     * 查询招商引资_附件
     * 
     * @param id 招商引资_附件ID
     * @return 招商引资_附件
     */
    @Override
    public ZsyzFj selectZsyzFjById(Long id)
    {
        return zsyzFjMapper.selectZsyzFjById(id);
    }

    /**
     * 查询招商引资_附件列表
     * 
     * @param zsyzFj 招商引资_附件
     * @return 招商引资_附件
     */
    @Override
    public List<ZsyzFj> selectZsyzFjList(ZsyzFj zsyzFj)
    {
        return zsyzFjMapper.selectZsyzFjList(zsyzFj);
    }

    /**
     * 新增招商引资_附件
     * 
     * @param zsyzFj 招商引资_附件
     * @return 结果
     */
    @Override
    public int insertZsyzFj(ZsyzFj zsyzFj)
    {
        return zsyzFjMapper.insertZsyzFj(zsyzFj);
    }

    /**
     * 修改招商引资_附件
     * 
     * @param zsyzFj 招商引资_附件
     * @return 结果
     */
    @Override
    public int updateZsyzFj(ZsyzFj zsyzFj)
    {
        return zsyzFjMapper.updateZsyzFj(zsyzFj);
    }

    /**
     * 批量删除招商引资_附件
     * 
     * @param ids 需要删除的招商引资_附件ID
     * @return 结果
     */
    @Override
    public int deleteZsyzFjByIds(Long[] ids)
    {
        return zsyzFjMapper.deleteZsyzFjByIds(ids);
    }

    /**
     * 删除招商引资_附件信息
     * 
     * @param id 招商引资_附件ID
     * @return 结果
     */
    @Override
    public int deleteZsyzFjById(Long id)
    {
        return zsyzFjMapper.deleteZsyzFjById(id);
    }
}
